Regex pattern validation rule.
Validates that a string value matches a given regex pattern. The regex is compiled once at first use via OnceLock in the generated code and passed as a reference to this validator.
Functions
- anchor_
pattern - Validate that the value matches the given regex pattern.
- validate_
pattern