pub trait AsStr {
// Required method
fn as_str_ref(&self) -> &str;
}Expand description
Trait for types that can be checked against a string pattern. Used by email, url, pattern, and contains validators.
Required Methods
Sourcefn as_str_ref(&self) -> &str
fn as_str_ref(&self) -> &str
Return this value as a string slice for pattern matching.